package com.persagy.dc.basic.utils;

import cn.hutool.core.util.IdUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.persagy.dc.basic.constant.DigitalObjectType;
import com.persagy.dc.common.constant.CommonConstant;
import com.persagy.dc.common.context.AppContext;
import com.persagy.dc.common.model.entity.BaseEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * 数据孪生通用工具
 * @author Charlie Yu
 * @date 2021-06-25
 */
public class DigitalCommonUtils {

    /**
     * 确认项目范围条件
     * @param wrapper 查询条件
     */
    public static <T extends BaseEntity> void ensureProjectCriteria(QueryWrapper<T> wrapper) {
        List<String> inSql = new ArrayList<>();
        // 0-平台级数据
        inSql.add(CommonConstant.DEFAULT_ID);
        // groupCode-集团级数据
        if(StrUtil.isNotBlank(AppContext.getContext().getGroupCode())) {
            inSql.add(AppContext.getContext().getGroupCode());
        }
        // projectId-项目级数据
        if(StrUtil.isNotBlank(AppContext.getContext().getProjectId())) {
            inSql.add(AppContext.getContext().getProjectId());
        }
        wrapper.in(StrUtil.toUnderlineCase(AppContext.PROJECT_ID), inSql);
    }

    /**
     * 确认项目范围条件
     * @param wrapper 查询条件
     */
    public static <T extends BaseEntity> void ensureProjectCriteria(QueryWrapper<T> wrapper, String projectId) {
        List<String> inSql = new ArrayList<>();
        // 0-平台级数据
        inSql.add(CommonConstant.DEFAULT_ID);
        // groupCode-集团级数据
        if(!CommonConstant.DEFAULT_ID.equalsIgnoreCase(projectId)) {
            inSql.add(AppContext.getContext().getGroupCode());
        }
        if(StrUtil.isNotBlank(projectId)) {
            inSql.add(projectId);
        }
        wrapper.in(StrUtil.toUnderlineCase(AppContext.PROJECT_ID), inSql);
    }

    /**
     * 获取数据范围ID
     * @return 0-平台级数据,groupCode-集团级数据,projectId-项目级数据
     */
    public static String getProjectId() {
        // projectId-项目级数据
        if(StrUtil.isNotBlank(AppContext.getContext().getProjectId())) {
            return AppContext.getContext().getProjectId();
        } else if(StrUtil.isNotBlank(AppContext.getContext().getGroupCode())) {
            // groupCode-集团级数据
            return AppContext.getContext().getGroupCode();
        } else {
            return CommonConstant.DEFAULT_ID;
        }
    }

    /**
     * 生成对象主键
     * @param projectId 项目ID
     * @param category 对象类型
     * @return 两位prefix + 无前缀projectId + simpleUUID
     */
    public static String fetchObjectId(String projectId, String category) {
        if (DigitalObjectType.PROJECT.getIndex().equalsIgnoreCase(category)) {
            return projectId;
        }
        String prefix = getIdPrefix(category);
        if(StrUtil.isBlank(prefix)) {
            return IdUtil.simpleUUID();
        }
        return prefix + projectId.substring(2) + IdUtil.simpleUUID();
    }

    /**
     * 根据对象类型获取Id前缀
     * @param category 对象类型
     * @return 两位的前缀 - 空字符串表示无效的对象类型
     */
    private static String getIdPrefix(String category) {
        if(DigitalObjectType.PROJECT.getIndex().equalsIgnoreCase(category)) {
            return "Pj";
        } else if (DigitalObjectType.BUILDING.getIndex().equalsIgnoreCase(category)) {
            return "Bd";
        } else if (DigitalObjectType.FLOOR.getIndex().equalsIgnoreCase(category)) {
            return "Fl";
        } else if (DigitalObjectType.SPACE.getIndex().equalsIgnoreCase(category)) {
            return "Sp";
        } else if (DigitalObjectType.SYSTEM.getIndex().equalsIgnoreCase(category)) {
            return "Sy";
        } else if (DigitalObjectType.EQUIPMENT.getIndex().equalsIgnoreCase(category)) {
            return "Eq";
        } else if (DigitalObjectType.SHAFT.getIndex().equalsIgnoreCase(category)) {
            return "Sh";
        } else if (DigitalObjectType.COMPONENT.getIndex().equalsIgnoreCase(category)) {
            return "Ec";
        } else if (DigitalObjectType.VIRTUAL.getIndex().equalsIgnoreCase(category)) {
            return "Vo";
        } else {
            return "";
        }
    }
}
