package com.persagy.dc.basic.utils;

import cn.hutool.json.JSONUtil;
import com.persagy.dc.amqp.handler.RabbitMessageSender;
import com.persagy.dc.basic.constant.DigitalMessageConstant;
import com.persagy.dc.basic.model.DigitalManageMessage;
import com.persagy.dc.common.model.entity.BaseEntity;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * 数据孪生消息发送助手
 * @author Charlie Yu
 * @date 2021-06-25
 */
@Component
public class DigitalMessageHelper {

    @Autowired
    private RabbitMessageSender messageSender;

    /**
     * 发送消息
     * @param operator 操作类型
     * @param oldVO 原数据
     * @param newVO 现数据
     * @param syncFlag 同步消息标识
     */
    public void sendMessage(String operator, BaseEntity oldVO, BaseEntity newVO, boolean syncFlag) {
        DigitalManageMessage message = new DigitalManageMessage();
        message.setOperatorType(operator);
        message.setOperatorObj(newVO.getClass().getSimpleName());
        message.setOldObj(oldVO);
        message.setNewObj(newVO);
        // 同步消息
        if(syncFlag) {
            messageSender.sendAndReceive(DigitalMessageConstant.MESSAGE_EXCHANGE,
                    DigitalMessageConstant.MESSAGE_ROUTING,
                    JSONUtil.toJsonStr(message));
        } else {
            // 异步消息
            messageSender.send(DigitalMessageConstant.MESSAGE_EXCHANGE,
                    DigitalMessageConstant.MESSAGE_ROUTING,
                    JSONUtil.toJsonStr(message));
        }
    }
}
