package com.persagy.dc.basic.utils;

import com.fasterxml.jackson.databind.JsonNode;

import java.io.IOException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * JsonNode 工具
 * @author Charlie Yu
 * @date 2021-06-25
 */
public class JsonNodeUtils {

    /**
     * 获取Node值
     * @param node 值节点
     * @return
     */
    public static Object getNodeValue(JsonNode node) {
        if(node.isContainerNode() || node.isNull()) {
            return null;
        }
        if(node.isBigDecimal()) {
            return node.decimalValue();
        }
        if(node.isBigInteger()) {
            return node.bigIntegerValue();
        }
        if(node.isBoolean()) {
            return node.booleanValue();
        }
        if(node.isBinary()) {
            try {
                return node.binaryValue();
            } catch (IOException e) {
                return null;
            }
        }
        if(node.isDouble()) {
            return node.doubleValue();
        }
        if(node.isFloat()) {
            return node.floatValue();
        }
        if(node.isInt()) {
            return node.intValue();
        }
        if(node.isLong()) {
            return node.longValue();
        }
        if(node.isNumber()) {
            return node.numberValue();
        }
        if(node.isShort()) {
            return node.shortValue();
        }
        if(node.isTextual()) {
            return node.textValue();
        }
        return null;
    }

    /**
     * 获取列表值
     * @param node 列表值类型节点
     * @return
     */
    public static List getListValue(JsonNode node) {
        if(!node.isArray()) {
            return null;
        }
        List values = new ArrayList<>(node.size());
        Iterator<JsonNode> elements = node.elements();
        while (elements.hasNext()) {
            values.add(getNodeValue(elements.next()));
        }
        return values;
    }
}
