package com.persagy.dc.define.service;

import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.dc.define.entity.ObjectType;

import java.util.List;
import java.util.Map;

/**
 * 对象类型 接口
 * @author Charlie Yu
 * @date 2021-06-25
 */
public interface IObjectTypeService {

    /**
     * 查询Map
     * @return <code, name>
     */
    Map<String, String> queryCodeNameMap();

    /**
     * 按项目、应用查询 - 支持订阅
     * @param projectId 项目ID
     * @param appId 应用ID
     * @return 列表结果
     */
    List<ObjectType> queryByProjectAndApp(String projectId, String appId);

    /**
     * 按项目、应用查询 - 支持订阅
     * @param page 分页条件
     * @param projectId 项目ID
     * @param appId 应用ID
     * @return 分页结果
     */
    Page queryByProjectAndApp(Page page, String projectId, String appId);

    /**
     * 按条件查询
     * @param queryWrapper 查询条件
     * @return 列表
     */
    List<ObjectType> queryByCondition(Wrapper<ObjectType> queryWrapper);

    /**
     * 按条件查询
     * @param page 分页条件
     * @param queryWrapper 查询条件
     * @return 分页结果
     */
    Page queryByCondition(Page page, Wrapper<ObjectType> queryWrapper);

    /**
     * 新增
     * @param voList 待新增数据
     * @return 新增后数据
     */
    List<ObjectType> insert(List<ObjectType> voList);

    /**
     * 修改
     * @param voList 待修改数据
     * @return 修改后数据
     */
    List<ObjectType> update(List<ObjectType> voList);

    /**
     * 删除
     * @param idList 主键
     */
    void delete(List<String> idList);
}
