package com.persagy.dc.digital.handler;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.persagy.dc.amqp.handler.AbstractRabbitHandlerTemplate;
import com.persagy.dc.common.exception.BusinessException;
import com.persagy.dc.digital.config.ProjectMessageConfig;
import com.persagy.dc.digital.entity.ObjectDigital;
import com.rabbitmq.client.Channel;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.core.Message;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;

import java.io.IOException;

/**
 * 项目消息消费
 * @author Charlie Yu
 * @date 2021-06-25
 */
@Slf4j
@RabbitListener(queues = ProjectMessageConfig.PROJECT_QUEUE)
public class ProjectMessageHandler extends AbstractRabbitHandlerTemplate {

    @Autowired
    private ObjectMapper objectMapper;

    /**
     * 消费
     * @param message 消息体字符串
     * @param channel 通道对象
     * @param vo     消息对象
     */
    @Override
    protected void handler(String message, Channel channel, Message vo) {
        try {
            ProjectMessageVO msgVO = objectMapper.readValue(message, ProjectMessageVO.class);
            ObjectDigital project = msgVO.toObjectDigital();
        } catch (IOException e) {
            log.error(e.getMessage(), e);
            throw new BusinessException(e.getMessage(), e);
        }
    }
}
