package com.persagy.dc.dic.controller;

import cn.hutool.core.util.StrUtil;
import com.persagy.dc.common.constant.ResponseCode;
import com.persagy.dc.common.exception.BusinessException;
import com.persagy.dc.common.model.response.CommonResult;
import com.persagy.dc.common.utils.ResultHelper;
import com.persagy.dc.dic.entity.DictType;
import com.persagy.dc.dic.service.DictTypeService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 字典类型
 * @author:linhuili
 * @date:2021/6/10
 */
@RestController
@RequestMapping(value = "/dic/type/")
public class DictTypeController {

    @Autowired
    private DictTypeService dictTypeService;

    @PostMapping("/create")
    public CommonResult<DictType> create(@RequestBody DictType dictType) {
        if(StrUtil.isBlank(dictType.getGroupCode())){
            throw new BusinessException(ResponseCode.A0400.getCode(), ResponseCode.A0400.getDesc());
        }
        DictType content = dictTypeService.create(dictType);
        return ResultHelper.single(content);
    }

    @PostMapping("/update")
    public CommonResult<DictType> update(@RequestBody DictType dictType) {
        if(StrUtil.isBlank(dictType.getGroupCode())|| StrUtil.isBlank(dictType.getId()) ){
            throw new BusinessException(ResponseCode.A0400.getCode(), ResponseCode.A0400.getDesc());
        }
        DictType content = dictTypeService.update(dictType);
        return ResultHelper.single(content);
    }

    @PostMapping("/delete")
    public CommonResult<DictType> delete(@RequestBody DictType dictType) {
        if(StrUtil.isBlank(dictType.getGroupCode()) || StrUtil.isBlank(dictType.getId()) ){
            throw new BusinessException(ResponseCode.A0400.getCode(), ResponseCode.A0400.getDesc());
        }
        DictType content = dictTypeService.delete(dictType);
        return ResultHelper.single(content);
    }

    @PostMapping("/query")
    public CommonResult<List<DictType>> query(@RequestBody DictType dictType) {
        if(StrUtil.isBlank(dictType.getGroupCode())){
            throw new BusinessException(ResponseCode.A0400.getCode(), ResponseCode.A0400.getDesc());
        }
        List<DictType> content = dictTypeService.query(dictType);
        return ResultHelper.single(content);
    }
}
